@@ -37,6 +37,9 @@ def get_allocation(client, id_or_name):
             allocations = client.allocations.list(**filters)
             if len(allocations) == 1:
                 return allocations[0]
+            elif len(allocations) > 1:
+                raise exceptions.CommandError(
+                    "'%s' matches more than one allocation" % id_or_name)
             else:
                 raise exceptions.NotFound()
     except exceptions.NotFound as ex:
@@ -137,7 +140,8 @@ class ListAllocations(command.Lister):
 
         allocations = client.allocations.list(**filters)
         columns = ['id', 'project_name',
-                   'contact_email', 'status_display']
+                   'contact_email', 'status_display', 'national',
+                   'associated_site']
 
         return (
             columns,
@@ -168,7 +172,8 @@ class AllocationHistory(command.Lister):
             parent_request=allocation.id)
         allocations.insert(0, allocation)
         columns = ['id', 'modified_time', 'status_display', 'start_date',
-                   'end_date', 'contact_email']
+                   'end_date', 'contact_email', 'national',
+                   'associated_site']
 
         return (
             columns,
